@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.1.
+ This file is part of the QGLViewer library version 2.3.4.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -27,8 +27,10 @@
 
 #if QT_VERSION >= 0x040000
 # include <QMap>
+# include <QClipboard>
 #else
 # include <qmap.h>
+# include <qclipboard.h>
 #endif
 
 class QTabWidget;
@@ -482,7 +484,7 @@ public:
 	saveAs pop-up dialog otherwise.
 
 	The available formats are those handled by Qt. Classical values are \c "JPEG", \c "PNG",
-	\c "PPM, \c "BMP". Use the following code to get the actual list:
+	\c "PPM", \c "BMP". Use the following code to get the actual list:
 	\code
 	QList<QByteArray> formatList = QImageReader::supportedImageFormats();
 	// or with Qt version 2 or 3:
@@ -524,22 +526,67 @@ public:
 	// Qt 2.3 does not support double default value parameters in slots.
 	// Remove "slots" from the following line to compile with Qt 2.3
 	public slots:
-		void saveSnapshot(bool automatic=true, bool overwrite=false);
+	void saveSnapshot(bool automatic=true, bool overwrite=false);
 
-		public slots:
-			void saveSnapshot(const QString& fileName, bool overwrite=false);
-			void setSnapshotFileName(const QString& name);
+	public slots:
+	void saveSnapshot(const QString& fileName, bool overwrite=false);
+	void setSnapshotFileName(const QString& name);
 
-			/*! Sets the snapshotFormat(). */
-			void setSnapshotFormat(const QString& format) { snapshotFormat_ = format; };
-			/*! Sets the snapshotCounter(). */
-			void setSnapshotCounter(int counter) { snapshotCounter_ = counter; };
-			/*! Sets the snapshotQuality(). */
-			void setSnapshotQuality(int quality) { snapshotQuality_ = quality; };
-			bool openSnapshotFormatDialog();
+	/*! Sets the snapshotFormat(). */
+	void setSnapshotFormat(const QString& format) { snapshotFormat_ = format; };
+	/*! Sets the snapshotCounter(). */
+	void setSnapshotCounter(int counter) { snapshotCounter_ = counter; };
+	/*! Sets the snapshotQuality(). */
+	void setSnapshotQuality(int quality) { snapshotQuality_ = quality; };
+	bool openSnapshotFormatDialog();
+	void snapshotToClipboard();
 
 private:
 	bool saveImageSnapshot(const QString& fileName);
+	
+#ifndef DOXYGEN
+	/* This class is used internally for screenshot that require tiling (image size size different
+	from window size). Only in that case, is the private tileRegion_ pointer non null.
+	It then contains the current tiled region, which is used by startScreenCoordinatesSystem
+	to adapt the coordinate system. Not using it would result in a tiled drawing of the parts
+	that use startScreenCoordinatesSystem. Also used by scaledFont for same purposes. */
+	class TileRegion { public : double xMin, yMin, xMax, yMax, textScale; };
+#endif
+
+public:
+	/*! Return a possibly scaled version of \p font, used for snapshot rendering.
+
+	From a user's point of view, this method simply returns \p font and can be used transparently.
+
+	However when internally rendering a screen snapshot using saveSnapshot(), it returns a scaled version 
+	of the font, so that the size of the rendered text on the snapshot is identical to what is displayed on screen, 
+	even if the snapshot uses image tiling to create an image of dimensions different from those of the
+	current window. This scaled version will only be used when saveSnapshot() calls your draw() method
+	to generate the snapshot.
+
+	All your calls to QGLWidget::renderText() function hence should use this method. 
+	\code
+	renderText(x, y, z, "My Text", scaledFont(QFont()));
+	\endcode
+	will guarantee that this text will be properly displayed on arbitrary sized snapshots.	
+
+	Note that this method is not needed if you use drawText() which already calls it internally. */
+	QFont scaledFont(const QFont& font) const {
+	  if (tileRegion_ == NULL)
+	    return font;
+	  else {
+	    QFont f(font);
+	    if (f.pixelSize() == -1)
+#if QT_VERSION >= 0x040000
+	      f.setPointSizeF(f.pointSizeF() * tileRegion_->textScale);
+#else
+	      f.setPointSizeFloat(f.pointSizeFloat() * tileRegion_->textScale);
+#endif
+	    else
+	      f.setPixelSize(f.pixelSize() * tileRegion_->textScale);
+	    return f;
+	  }
+	}
 	//@}
 
 
@@ -885,7 +932,7 @@ protected:
 	enum KeyboardAction { DRAW_AXIS, DRAW_GRID, DISPLAY_FPS, ENABLE_TEXT, EXIT_VIEWER,
 		SAVE_SCREENSHOT, CAMERA_MODE, FULL_SCREEN, STEREO, ANIMATION, HELP, EDIT_CAMERA,
 		MOVE_CAMERA_LEFT, MOVE_CAMERA_RIGHT, MOVE_CAMERA_UP, MOVE_CAMERA_DOWN,
-		INCREASE_FLYSPEED, DECREASE_FLYSPEED };
+		INCREASE_FLYSPEED, DECREASE_FLYSPEED, SNAPSHOT_TO_CLIPBOARD };
 public:
 	int shortcut(KeyboardAction action) const;
 #ifndef DOXYGEN
@@ -1206,8 +1253,10 @@ private:
 
 	// S n a p s h o t s
 	void initializeSnapshotFormats();
+	QImage frameBufferSnapshot();
 	QString snapshotFileName_, snapshotFormat_;
 	int snapshotCounter_, snapshotQuality_;
+	TileRegion* tileRegion_;
 
 	// Q G L V i e w e r   p o o l
 #if QT_VERSION >= 0x040000
