@@ -1,89 +1,73 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="fr">
+<!DOCTYPE TS>
+<TS version="2.0" language="fr_FR">
 <context>
     <name>ImageInterface</name>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="13"/>
         <source>Image settings</source>
         <translation>Réglages d&apos;image</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="54"/>
         <source>Width</source>
         <translation>Largeur</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="100"/>
         <source> px</source>
         <translation> px</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="61"/>
         <source>Width of the image (in pixels)</source>
         <translation>Largeur de l&apos;image (en pixels)</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="90"/>
         <source>Height</source>
         <translation>Hauteur</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="97"/>
         <source>Height of the image (in pixels)</source>
         <translation>Hauteur de l&apos;image (en pixels)</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="132"/>
         <source>Image quality</source>
         <translation>Qualité d&apos;image</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="139"/>
         <source>Between 0 (smallest files) and 100 (highest quality)</source>
         <translation>Entre 0 (taille de fichier minimale) et 100 (qualité maximale)</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="184"/>
         <source>Oversampling</source>
         <translation>Suréchantillonage</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="194"/>
         <source>x </source>
         <translation>x </translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="191"/>
         <source>Antialiases image (when larger then 1.0)</source>
         <translation>Anti-alliassage de l&apos;image (si supérieur à 1.0)</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="234"/>
         <source>Use white background</source>
         <translation>Fond blanc</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="231"/>
         <source>Use white as background color</source>
         <translation>Mettre du blanc en couleur de fond</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="244"/>
         <source>Expand frustum if needed</source>
         <translation>Etendre la pyramide de vue ( frustum) si nécessaire</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="241"/>
         <source>When image aspect ratio differs from viewer&apos;s one, expand frustum as needed. Fits inside current frustum otherwise.</source>
         <translation>Lorsque le rapport de dimensions de l&apos;image diffère de celui de la fenêtre, étendre la pyramide de vue (frustum) en conséquence. L&apos;image est ajustée à l&apos;intérieur de la vue actuelle sinon. </translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="294"/>
         <source>OK</source>
         <translation>Ok</translation>
     </message>
     <message>
-        <location filename="ImageInterface.Qt4.ui" line="301"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
@@ -91,576 +75,482 @@
 <context>
     <name>QGLViewer</name>
     <message>
-        <location filename="qglviewer.cpp" line="114"/>
         <source>snapshot</source>
         <comment>Default snapshot file name</comment>
         <translation>capture</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="478"/>
         <source>%1Hz</source>
         <comment>Frames per seconds, in Hertz</comment>
         <translation>%1Hz</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="291"/>
         <source>About libQGLViewer</source>
         <comment>About message box title</comment>
         <translation>A propos de libQGLViewer</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="584"/>
         <source>Toggles the display of the FPS</source>
         <comment>DISPLAY_FPS action description</comment>
         <translation>Active ou non l&apos;affichage de la fréquence d&apos;affiichage</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="585"/>
         <source>Saves a screenshot</source>
         <comment>SAVE_SCREENSHOT action description</comment>
         <translation>Sauvegarde une capture d&apos;écran</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="586"/>
         <source>Toggles full screen display</source>
         <comment>FULL_SCREEN action description</comment>
         <translation>Passe ou non en mode plein écran</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="587"/>
         <source>Toggles the display of the world axis</source>
         <comment>DRAW_AXIS action description</comment>
         <translation>Affiche ou non le repère du monde</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="588"/>
         <source>Toggles the display of the XY grid</source>
         <comment>DRAW_GRID action description</comment>
         <translation>Affiche ou non la grille XY</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="589"/>
         <source>Changes camera mode (revolve or fly)</source>
         <comment>CAMERA_MODE action description</comment>
         <translation>Change le mode de la caméra (observateur ou vol)</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="590"/>
         <source>Toggles stereo display</source>
         <comment>STEREO action description</comment>
         <translation>Affiche ou non en stéréo</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="591"/>
         <source>Opens this help window</source>
         <comment>HELP action description</comment>
         <translation>Ouvre la fenêtre d&apos;aide</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="592"/>
         <source>Starts/stops the animation</source>
         <comment>ANIMATION action description</comment>
         <translation>Démarre/arrête l&apos;animation</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="593"/>
         <source>Toggles camera paths display</source>
         <comment>EDIT_CAMERA action description</comment>
         <translation>Affiche ou non les chemins de caméra</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="594"/>
         <source>Toggles the display of the text</source>
         <comment>ENABLE_TEXT action description</comment>
         <translation>Affiche ou non les textes</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="595"/>
         <source>Exits program</source>
         <comment>EXIT_VIEWER action description</comment>
         <translation>Quitte l&apos;application</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="596"/>
         <source>Moves camera left</source>
         <comment>MOVE_CAMERA_LEFT action description</comment>
         <translation>Déplace la caméra sur la gauche</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="597"/>
         <source>Moves camera right</source>
         <comment>MOVE_CAMERA_RIGHT action description</comment>
         <translation>Déplace la caméra sur la droite</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="598"/>
         <source>Moves camera up</source>
         <comment>MOVE_CAMERA_UP action description</comment>
         <translation>Déplace la caméra vers le haut</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="599"/>
         <source>Moves camera down</source>
         <comment>MOVE_CAMERA_DOWN action description</comment>
         <translation>Déplace la caméra vers le bas</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="600"/>
         <source>Increases fly speed</source>
         <comment>INCREASE_FLYSPEED action description</comment>
         <translation>Augmente la vitesse de vol</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="601"/>
         <source>Decreases fly speed</source>
         <comment>DECREASE_FLYSPEED action description</comment>
         <translation>Diminue la vitesse de vol</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1759"/>
+        <source>Copies a snapshot to clipboard</source>
+        <comment>SNAPSHOT_TO_CLIPBOARD action description</comment>
+        <translation>Place une capture d&apos;écran dans le presse-papier</translation>
+    </message>
+    <message>
         <source>Stereo not supported</source>
         <comment>Message box window title</comment>
         <translation>Stéréo non supportée</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1759"/>
         <source>Stereo is not supported on this display.</source>
         <translation>Affichage en stéréo non supporté sur cette machine.</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1835"/>
         <source>(no button)</source>
         <translation>(pas de bouton)</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="295"/>
         <source>libQGLViewer, version %1.&lt;br&gt;A versatile 3D viewer based on OpenGL and Qt.&lt;br&gt;Copyright 2002-%2 Gilles Debunne.&lt;br&gt;&lt;code&gt;%3&lt;/code&gt;</source>
         <translation>libQGLViewer, version %1.&lt;br&gt;Un visualiseur 3D générique basé sur OpenGL et Qt.&lt;br&gt;Copyright 2002-%2 Gilles Debunne.&lt;br&gt;&lt;code&gt;%3&lt;/code&gt;</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1855"/>
         <source>Rotates</source>
         <comment>ROTATE mouse action</comment>
         <translation>Tourne</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1856"/>
         <source>Zooms</source>
         <comment>ZOOM mouse action</comment>
         <translation>Zoome</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1857"/>
         <source>Translates</source>
         <comment>TRANSLATE mouse action</comment>
         <translation>Translate</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1860"/>
         <source>Moves backward</source>
         <comment>MOVE_BACKWARD mouse action</comment>
         <translation>Recule</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1864"/>
         <source>Horizontally/Vertically translates</source>
         <comment>SCREEN_TRANSLATE mouse action</comment>
         <translation>Translate horizontalement/verticalement</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1858"/>
         <source>Moves forward</source>
         <comment>MOVE_FORWARD mouse action</comment>
         <translation>Avance</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1859"/>
         <source>Looks around</source>
         <comment>LOOK_AROUND mouse action</comment>
         <translation>Regarde</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1861"/>
         <source>Rotates in screen plane</source>
         <comment>SCREEN_ROTATE mouse action</comment>
         <translation>Pivote dans le plan écran</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1862"/>
         <source>Rolls</source>
         <comment>ROLL mouse action</comment>
         <translation>Pivote</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1863"/>
         <source>Drives</source>
         <comment>DRIVE mouse action</comment>
         <translation>Avance</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1865"/>
         <source>Zooms on region for</source>
         <comment>ZOOM_ON_REGION mouse action</comment>
         <translation>Zoome sur la région pour</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1875"/>
         <source>Zooms on pixel</source>
         <comment>ZOOM_ON_PIXEL click action</comment>
         <translation>Zoome sur le pixel</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1876"/>
         <source>Zooms to fit scene</source>
         <comment>ZOOM_TO_FIT click action</comment>
         <translation>Zoome pour ajuster à la scène</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1877"/>
         <source>Selects</source>
         <comment>SELECT click action</comment>
         <translation>Sélectionne</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1878"/>
         <source>Sets revolve around point</source>
         <comment>RAP_FROM_PIXEL click action</comment>
         <translation>Définit le point de rotation</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1879"/>
         <source>Resets revolve around point</source>
         <comment>RAP_IS_CENTER click action</comment>
         <translation>Restaure le point de rotation</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1880"/>
         <source>Centers frame</source>
         <comment>CENTER_FRAME click action</comment>
         <translation>Centre le repère manipulé</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1881"/>
         <source>Centers scene</source>
         <comment>CENTER_SCENE click action</comment>
         <translation>Centre la scène</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1882"/>
         <source>Shows entire scene</source>
         <comment>SHOW_ENTIRE_SCENE click action</comment>
         <translation>Affiche toute la scène</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1883"/>
         <source>Aligns frame</source>
         <comment>ALIGN_FRAME click action</comment>
         <translation>Aligne le repère manipulé</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1884"/>
         <source>Aligns camera</source>
         <comment>ALIGN_CAMERA click action</comment>
         <translation>Aligne la caméra</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2242"/>
         <source>Camera paths are controlled using %1 (noted &lt;i&gt;Fx&lt;/i&gt; below):</source>
         <comment>Help window key tab camera keys</comment>
         <translation>Les chemins de caméra sont contrôlés avec %1 (noté &lt;i&gt;Fx&lt;/i&gt; ci-dessous) :</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2206"/>
         <source>Key(s)</source>
         <comment>Keys column header in help window mouse tab</comment>
         <translation>Touche(s)</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2206"/>
         <source>Description</source>
         <comment>Description column header in help window mouse tab</comment>
         <translation>Description</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2223"/>
         <source>Standard viewer keys</source>
         <comment>In help window keys tab</comment>
         <translation>Raccourcis standards</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2247"/>
         <source>Fx</source>
         <comment>Generic function key (F1..F12)</comment>
         <translation>Fx</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2244"/>
         <source>Plays path (or resets saved position)</source>
         <translation>Joue le chemin (ou restaure la position sauvegardée)</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2246"/>
         <source>Adds a key frame to path (or defines a position)</source>
         <translation>Ajoute une position clef au chemin (ou définit une position)</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2248"/>
         <source>Deletes path (or saved position)</source>
         <translation>Supprime le chemin (ou la position)</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1984"/>
         <source>Button(s)</source>
         <comment>Buttons column header in help window mouse tab</comment>
         <translation>Bouton(s)</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2005"/>
         <source>Standard mouse bindings</source>
         <comment>In help window mouse tab</comment>
         <translation>Actions souris standards</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1894"/>
         <source>Wheel</source>
         <comment>Mouse wheel</comment>
         <translation>Molette</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2273"/>
         <source>&amp;Help</source>
         <comment>Help window tab title</comment>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2273"/>
         <source>&amp;Keyboard</source>
         <comment>Help window tab title</comment>
         <translation>&amp;Clavier</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2273"/>
         <source>&amp;Mouse</source>
         <comment>Help window tab title</comment>
         <translation>&amp;Souris</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2282"/>
         <source>Help</source>
         <comment>Help window title</comment>
         <translation>Aide</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2286"/>
         <source>About</source>
         <comment>About button in help window</comment>
         <translation>A propos</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2437"/>
         <source>Path %1 deleted</source>
         <comment>Feedback message</comment>
         <translation>Chemin %1 supprimé</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2439"/>
         <source>Position %1 deleted</source>
         <comment>Feedback message</comment>
         <translation>Position %1 supprimée</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2451"/>
         <source>Path %1, position %2 added</source>
         <comment>Feedback message</comment>
         <translation>Chemin %1, position %2 ajoutée</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2453"/>
         <source>Position %1 saved</source>
         <comment>Feedback message</comment>
         <translation>Position %1 sauvegardée</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2480"/>
         <source>Camera in revolve around mode</source>
         <comment>Feedback message</comment>
         <translation>Caméra en mode observateur</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2480"/>
         <source>Camera in fly mode</source>
         <comment>Feedback message</comment>
         <translation>Caméra en mode vol</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="3616"/>
         <source>Save to file error</source>
         <comment>Message box window title</comment>
         <translation>Erreur lors de la sauvegarde</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="3574"/>
         <source>State file name (%1) references a directory instead of a file.</source>
         <translation>Le nom du fichier d&apos;état (%1) référence un répértoire et non un fichier.</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="3592"/>
         <source>Unable to create directory %1</source>
         <translation>Le répértoire %1 ne peut être créé</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="3616"/>
         <source>Unable to save to file %1</source>
         <translation>Impossible de sauvegarder le fichier %1</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="3655"/>
         <source>Problem in state restoration</source>
         <comment>Message box window title</comment>
         <translation>Problème lors de la restauration de l&apos;état</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="3655"/>
         <source>File %1 is not readable.</source>
         <translation>Le fichier %1 n&apos;est pas lisible.</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="3678"/>
         <source>Open file error</source>
         <comment>Message box window title</comment>
         <translation>Erreur d&apos;ouverture de fichier</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="3678"/>
         <source>Unable to open file %1</source>
         <translation>Le fichier %1 ne peut être ouvert</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1829"/>
         <source>Ctrl+</source>
         <comment>Modifier key</comment>
         <translation>Ctrl+</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1830"/>
         <source>Alt+</source>
         <comment>Modifier key</comment>
         <translation>Alt+</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1831"/>
         <source>Shift+</source>
         <comment>Modifier key</comment>
         <translation>Shift+</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1833"/>
         <source>Meta+</source>
         <comment>Modifier key</comment>
         <translation>Méta+</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1844"/>
         <source>Left</source>
         <comment>left mouse button</comment>
         <translation>Gauche</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1845"/>
         <source>Middle</source>
         <comment>middle mouse button</comment>
         <translation>Milieu</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1846"/>
         <source>Right</source>
         <comment>right mouse button</comment>
         <translation>Droit</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1895"/>
         <source> double click</source>
         <comment>Suffix after mouse button</comment>
         <translation>Double clic </translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2050"/>
         <source>camera</source>
         <comment>Suffix after action</comment>
         <translation>la caméra</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="2051"/>
         <source>manipulated frame</source>
         <comment>Suffix after action</comment>
         <translation>le repère manipulé</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1896"/>
         <source> with </source>
         <comment>As in : Left button with Ctrl pressed</comment>
         <translation> avec </translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1898"/>
         <source> pressed</source>
         <comment>As in : Left button with Ctrl pressed</comment>
         <translation> enfoncé</translation>
     </message>
     <message>
-        <location filename="qglviewer.cpp" line="1893"/>
         <source>%1%2%3%4%5%6</source>
         <comment>Modifier / button or wheel / double click / with / button / pressed</comment>
         <translation>%1%3%2%4%5%6</translation>
     </message>
     <message>
-        <location filename="qglviewer.h" line="670"/>
         <source>No help available.</source>
         <translation>Pas d&apos;aide disponible.</translation>
     </message>
     <message>
-        <location filename="VRender/Exporter.cpp" line="29"/>
         <source>Exporter error</source>
         <comment>Message box window title</comment>
         <translation>Erreur d&apos;export</translation>
     </message>
     <message>
-        <location filename="VRender/Exporter.cpp" line="29"/>
         <source>Unable to open file %1.</source>
         <translation>Impossible d&apos;ouvrir le ficher %1.</translation>
     </message>
     <message>
-        <location filename="VRender/BSPSortMethod.cpp" line="69"/>
         <source>BSP Construction</source>
         <translation>Construction du BSP</translation>
     </message>
     <message>
-        <location filename="VRender/Exporter.cpp" line="50"/>
         <source>Exporting to file %1</source>
         <translation>Export vers le fichier %1</translation>
     </message>
     <message>
-        <location filename="VRender/ParserGL.cpp" line="85"/>
         <source>Parsing feedback buffer.</source>
         <translation>Parcours du feedback buffer.</translation>
     </message>
     <message>
-        <location filename="VRender/TopologicalSortMethod.cpp" line="344"/>
         <source>Topological sort</source>
         <translation>Tri topologique</translation>
     </message>
     <message>
-        <location filename="VRender/TopologicalSortMethod.cpp" line="636"/>
         <source>Advanced topological sort</source>
         <translation>Tri topologique avancé</translation>
     </message>
     <message>
-        <location filename="VRender/VRender.cpp" line="39"/>
         <source>Rendering...</source>
         <translation>Rendu...</translation>
     </message>
     <message>
-        <location filename="VRender/VisibilityOptimizer.cpp" line="221"/>
         <source>Visibility optimization</source>
         <translation>Optimisation de la visibilité</translation>
     </message>
@@ -668,97 +558,78 @@
 <context>
     <name>VRenderInterface</name>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="13"/>
         <source>Vectorial rendering options</source>
         <translation>Options de rendu vectoriel</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="37"/>
         <source>Include hidden parts</source>
         <translation>Inclure les parties cachées</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="47"/>
         <source>Cull back faces</source>
         <translation>Supprimer les faces arrières</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="44"/>
         <source>Back faces (non clockwise point ordering) are removed from the output</source>
         <translation>Les  faces orientées vers l&apos;arrière (points ordonnés dans le sens anti-horaire) sont supprimées du résultat (Back Face Culling)</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="57"/>
         <source>Black and white</source>
         <translation>Noir et blanc</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="54"/>
         <source>Black and white rendering</source>
         <translation>Rendu en noir et blanc</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="67"/>
         <source>Color background</source>
         <translation>Fond avec une couleur</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="64"/>
         <source>Use current background color instead of white</source>
         <translation>Utiliser la couleur de fond actuelle à la place du blanc</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="77"/>
         <source>Tighten bounding box</source>
         <translation>Ajuster la boîte englobante</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="74"/>
         <source>Fit output bounding box to current display</source>
         <translation>Ajuster la boîte englobante de la sortie à ce qui est actuellement affiché</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="111"/>
         <source>Polygon depth sorting method</source>
         <translation>Méthode de tri de la profondeur des polygônes</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="118"/>
         <source>No sorting</source>
         <translation>Pas de tri</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="128"/>
         <source>Topological</source>
         <translation>Topologique</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="133"/>
         <source>Advanced topological</source>
         <translation>Topologique avancé</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="176"/>
         <source>Save</source>
         <translation>Sauvegarder</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="183"/>
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="34"/>
         <source>Hidden polygons are also included in the output (usually twice bigger)</source>
         <translation>Inclure les polygônes cachés dans le résultat (alors habituellement deux fois plus gros)</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="104"/>
         <source>Sort method:</source>
         <translation>Méthode de tri :</translation>
     </message>
     <message>
-        <location filename="VRenderInterface.Qt4.ui" line="123"/>
         <source>BSP</source>
         <translation>BSP</translation>
     </message>
