@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.1.
+ This file is part of the QGLViewer library version 2.3.4.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -652,8 +652,7 @@ DvonnViewer::mouseMoveEvent(QMouseEvent* e)
 #else
   if ((dragToPlay_ && e->stateAfter() == Qt::LeftButton) ||
 #endif
-      (!dragToPlay_ && !srcPicked_ .isNull()) &&
-      !camera()->frame()->isManipulated())
+      ( (!dragToPlay_) && (!srcPicked_.isNull()) && (!camera()->frame()->isManipulated()) ) )
   {
     if (game_->phase() == RedPlacementPhase ||
 	game_->phase() == PiecePlacementPhase)
