@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.1.
+ This file is part of the QGLViewer library version 2.3.4.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -34,7 +34,11 @@ bool TERRAIN::LoadHeightMap(const QString& filename, int size)
     UnloadHeightMap( );
 
   QFile pFile(filename);
-  if (!pFile.open(QIODevice::ReadOnly | QIODevice::Text))
+#if QT_VERSION >= 0x040000
+	if (!pFile.open(QIODevice::ReadOnly))
+#else
+	if (!pFile.open(IO_ReadOnly))
+#endif
     return false;
 
   heightMap.arrayHeightMap = new unsigned char [size*size];
@@ -58,7 +62,11 @@ bool TERRAIN::LoadHeightMap(const QString& filename, int size)
 bool TERRAIN::SaveHeightMap(const QString& filename )
 {
   QFile pFile(filename);
-  if (!pFile.open(QIODevice::WriteOnly | QIODevice::Text))
+#if QT_VERSION >= 0x040000
+	if (!pFile.open(QIODevice::WriteOnly))
+#else
+	if (!pFile.open(IO_WriteOnly))
+#endif
     return false;
 
   if( heightMap.arrayHeightMap==NULL )
