@@ -2,7 +2,7 @@
 
  Copyright (C) 2002-2008 Gilles Debunne. All rights reserved.
 
- This file is part of the QGLViewer library version 2.3.1.
+ This file is part of the QGLViewer library version 2.3.4.
 
  http://www.libqglviewer.com - contact@libqglviewer.com
 
@@ -79,7 +79,7 @@ void Box::drawIfAllChildrenAreVisible(const CullingCamera* camera) const
 {
   static bool* entirely = new bool;
 
-  if (camera->aaBoxIsVisible(p1, p2, entirely))
+  if (camera->aaBoxIsVisible(p1, p2, entirely)) {
     if (*entirely)
       draw();
     else
@@ -88,4 +88,5 @@ void Box::drawIfAllChildrenAreVisible(const CullingCamera* camera) const
 	  child[i]->drawIfAllChildrenAreVisible(camera);
       else
 	draw();
+  }
 }
